Permit

Struct Permit 

pub struct Permit<'a, T> {
    chan: &'a Tx<T, Semaphore>,
}
Permits to send one value into the channel.

Permit values are returned by Sender::reserve() and Sender::try_reserve() and are used to guarantee channel capacity before generating a message to send.

Fields

chan: &'a Tx<T, Semaphore>

Implementations



impl<T> Permit<'_, T>

pub fn send(self, value: T)

Sends a value using the reserved capacity.

Capacity for the message has already been reserved. The message is sent to the receiver and the permit is consumed. The operation will succeed even if the receiver half has been closed. See Receiver::close for more details on performing a clean shutdown.

Examples
use tokio::sync::mpsc;

let (tx, mut rx) = mpsc::channel(1);

// Reserve capacity
let permit = tx.reserve().await.unwrap();

// Trying to send directly on the `tx` will fail due to no
// available capacity.
assert!(tx.try_send(123).is_err());

// Send a message on the permit
permit.send(456);

// The value sent on the permit is received
assert_eq!(rx.recv().await.unwrap(), 456);